@@ -53,9 +53,11 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
 
         props |= Item.props.relevant
         props |= Item.props.man_input
+        props |= Item.props.confirmed
 
         delAttr(_data, 'relevant')
         delAttr(_data, 'where_from')
+        delAttr(_data, 'confirmed')
         setAttr(_data, 'props', props)
 
         res = super().create(**_data)
@@ -97,11 +99,12 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
     @staticmethod
     def delete_recursive(item_id, delete_lines=False, soft_delete=False, user=None, props=TurnBitOn(0, 0), document=None, show_progress=True):
         from isc_common.models.deleted_progresses import Deleted_progresses
+        from kaf_pas.ckk.models.item_document import Item_document
         from kaf_pas.ckk.models.item_image_refs import Item_image_refs
         from kaf_pas.ckk.models.item_line import Item_line
         from kaf_pas.ckk.models.item_refs import Item_refs
+        from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
         from kaf_pas.production.models.operations_item import Operations_item
-        from kaf_pas.ckk.models.item_document import Item_document
 
         settings.LOCKS.acquire('ItemManager.delete_recursive')
         item_lotsman_document_cnt = 0
@@ -155,6 +158,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         def _delete(progress=None):
             try:
                 with transaction.atomic():
+                    Tmp_Item_refsManager.create()
                     try:
                         item = Item.objects.get(id=item_id)
                         if cnt == 0:
