@@ -133,11 +133,16 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
         return None, None
 
     def get_ex1(self, *args, **kwargs):
+        from kaf_pas.kd.models.lotsman_documents_hierarcy import Lotsman_documents_hierarcy
+        from kaf_pas.kd.models.uploades_documents import Uploades_documents
+
         file_name = kwargs.get('file_document')
         file_drive = kwargs.get('file_drive')
         virt_path = kwargs.get('virt_path')
         attr_type = kwargs.get('attr_type')
-        delAttr(kwargs, 'file_document')
+        file_document = kwargs.get('file_document')
+        path = kwargs.get('path')
+        for_delete=None
 
         if virt_path:
             if virt_path[0:1] == os.sep or virt_path[0:1] == os.altsep:
@@ -151,7 +156,7 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
         else:
             _file_name = file_name.replace(os.altsep, os.sep)
 
-        for doc in Documents.objects.filter(path=kwargs.get('path'), attr_type=attr_type).exclude(attr_type=self.type_bad):
+        for doc in Documents.objects.filter(path=path, attr_type=attr_type, file_document=file_document).exclude(attr_type=self.type_bad):
             real_file = replace_alt_set(f'{file_drive}{os.sep}{file_name}')
 
             if replace_alt_set(doc.file_document) == replace_alt_set(_file_name):
@@ -180,7 +185,15 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
                 #     return doc, True
                 else:
                     # Для импорта из Лоцмана т.к. состоит из многих узлов,  которые закачиваются сами по себе
-                    return doc, False
+
+                    if Lotsman_documents_hierarcy.objects.filter(document=doc).count() > 0:
+                        return doc, False
+                    else:
+                        for_delete=doc.id
+
+            Uploades_documents.objects.filter(document_id=for_delete).delete()
+            Documents.objects.filter(id=for_delete).delete()
+            return None, None
         return None, None
 
     def updateFromRequest(self, request, removed=None, function=None):
