@@ -86,45 +86,19 @@ class DocumentManagerExt:
                 if STMP_1 != None or STMP_2 != None:
                     props = Item.props.relevant | Item.props.from_spw
 
-                    if STMP_1 == None:
-                        item_query = Item.objects.filter(
-                            STMP_2__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2.value_str),
-                            props=props
-                        )
-                    elif STMP_2 == None:
-                        item_query = Item.objects.filter(
-                            STMP_1__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1.value_str),
-                            props=props
-                        )
-                    else:
-                        item_query = Item.objects.filter(
-                            STMP_1__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1.value_str),
-                            STMP_2__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2.value_str),
-                            props=props
-                        )
+                    version = ItemManager.get_verstion(
+                        STMP_1=Document_attributes.objects.get(id=STMP_1.id) if STMP_1 else None,
+                        STMP_2=Document_attributes.objects.get(id=STMP_2.id) if STMP_2 else None,
+                        props=props
+                    )
 
-                    parent_count = 0
-                    for item in item_query:
-                        parent_count = Item_refs.objects.filter(parent=item).count()
-                        if parent_count > 0:
-                            break
-
-                    version = 0
-                    if parent_count > 0:
-                        version = ItemManager.get_verstion(STMP_1=STMP_1, STMP_2=STMP_2, props=Item.props.from_spw)
-
-                    while True:
-                        try:
-                            parent = Item.objects.create(
-                                STMP_1_id=STMP_1.id if STMP_1 else None,
-                                STMP_2_id=STMP_2.id if STMP_2 else None,
-                                props=props,
-                                document=document,
-                                version=version
-                            )
-                            break
-                        except IntegrityError:
-                            version += 1
+                    parent = Item.objects.create(
+                        STMP_1_id=STMP_1.id if STMP_1 else None,
+                        STMP_2_id=STMP_2.id if STMP_2 else None,
+                        props=props,
+                        document=document,
+                        version=version
+                    )
 
                     Item_refs.objects.create(parent_id=int(top_level.value), child=parent)
                     self.link_image_to_item(parent)
@@ -240,10 +214,11 @@ class DocumentManagerExt:
 
     def make_cdw(self, document):
         from kaf_pas.ckk.models.item import Item
+        from kaf_pas.ckk.models.item import ItemManager
         from kaf_pas.ckk.models.item_refs import Item_refs
+        from kaf_pas.kd.models.document_attributes import Document_attributes
         from kaf_pas.kd.models.documents import Documents
         from kaf_pas.system.models.contants import Contants
-        from kaf_pas.ckk.models.item import ItemManager
 
         top_level = Contants.objects.get(code='audo_top_level')
 
@@ -265,28 +240,21 @@ class DocumentManagerExt:
                     STMP_2 = Document_attributes_view.objects.filter(document=document, attr_type__code='STMP_2')[0]
 
                 if STMP_1 != None or STMP_2 != None:
-                    cnt = Item.objects.filter(
-                        STMP_1__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1.value_str) if STMP_1 else None,
-                        STMP_2__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2.value_str) if STMP_2 else None,
-                        props=Item.props.relevant | Item.props.from_cdw,
-                    ).count()
 
-                    version = 0
-                    if cnt != 0:
-                        version = ItemManager.get_verstion(STMP_1=STMP_1, STMP_2=STMP_2, props=Item.props.relevant | Item.props.from_cdw)
+                    props = Item.props.relevant | Item.props.from_cdw
+                    version = ItemManager.get_verstion(
+                        STMP_1=Document_attributes.objects.get(id=STMP_1.id) if STMP_1 else None,
+                        STMP_2=Document_attributes.objects.get(id=STMP_2.id) if STMP_2 else None,
+                        props=props
+                    )
 
-                    while True:
-                        try:
-                            item = Item.objects.create(
-                                STMP_1_id=STMP_1.id if STMP_1 else None,
-                                STMP_2_id=STMP_2.id if STMP_2 else None,
-                                props=Item.props.relevant | Item.props.from_cdw,
-                                document=document,
-                                version=version
-                            )
-                            break
-                        except IntegrityError:
-                            version += 1
+                    item = Item.objects.create(
+                        STMP_1_id=STMP_1.id if STMP_1 else None,
+                        STMP_2_id=STMP_2.id if STMP_2 else None,
+                        props=props,
+                        document=document,
+                        version=version
+                    )
 
                     Item_refs.objects.get_or_create(parent_id=int(top_level.value), child=item)
                     self.link_image_to_item(item)
@@ -330,28 +298,17 @@ class DocumentManagerExt:
                 except Document_attributes.MultipleObjectsReturned:
                     STMP_2_attr = Document_attributes.objects.filter(value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2), attr_type=STMP_2_type)[0]
 
-                cnt = Item.objects.filter(
-                    STMP_1__value_str__delete_dbl_spaces=STMP_1,
-                    STMP_2__value_str__delete_dbl_spaces=STMP_2,
-                    props=Item.props.relevant | Item.props.from_pdf,
-                ).count()
 
-                version = 0
-                if cnt != 0:
-                    version = ItemManager.get_verstion(STMP_1=STMP_1_attr, STMP_2=STMP_2_attr, props=Item.props.from_pdf)
+                props = Item.props.relevant | Item.props.from_pdf
+                version = ItemManager.get_verstion(STMP_1=STMP_1_attr, STMP_2=STMP_2_attr, props=props)
 
-                while True:
-                    try:
-                        item = Item.objects.create(
-                            STMP_1=STMP_1_attr,
-                            STMP_2=STMP_2_attr,
-                            props=Item.props.relevant | Item.props.from_pdf,
-                            document=document,
-                            version=version
-                        )
-                        break
-                    except IntegrityError:
-                        version += 1
+                item = Item.objects.create(
+                    STMP_1=STMP_1_attr,
+                    STMP_2=STMP_2_attr,
+                    props=props,
+                    document=document,
+                    version=version
+                )
 
                 Item_refs.objects.get_or_create(parent_id=int(top_level.value), child=item)
                 self.link_image_to_item(item)
