@@ -1,15 +1,16 @@
 import logging
 
 from django.db import connection
-from django.db.models import BigIntegerField, BooleanField, PositiveIntegerField, TextField
+from django.db.models import BigIntegerField, BooleanField
 
+from isc_common import setAttr
 from isc_common.fields.name_field import NameField
 from isc_common.fields.related import ForeignKeyProtect, ForeignKeySetNull
 from isc_common.http.DSRequest import DSRequest
 from isc_common.models.audit import AuditManager, AuditQuerySet, AuditModel
-from isc_common.models.base_ref import Hierarcy
 from isc_common.models.tree_audit import TreeAuditModelManager
 from isc_common.number import DelProps
+from isc_common.string import get_NoneStr
 from kaf_pas.ckk.models.attr_type import Attr_type
 from kaf_pas.kd.models.document_attributes import Document_attributes
 from kaf_pas.kd.models.documents import Documents
@@ -25,11 +26,11 @@ class Lotsman_documents_hierarcy_viewQuerySet(AuditQuerySet):
         with connection.cursor() as cursor:
             cursor.execute(f'''select min(level)
             from kd_lotsman_documents_hierarcy_recurs_view
-            where document_id = %s''',[kwargs.get('document_id')])
+            where document_id = %s''', [kwargs.get('document_id')])
             level_min = cursor.fetchone()[0]
 
             if level_min == None:
-                level_min=1
+                level_min = 1
 
             cursor.execute(f'''SELECT 'SELECT case when a.level = {level_min} then null
                                        else a.parent_id
@@ -37,7 +38,7 @@ class Lotsman_documents_hierarcy_viewQuerySet(AuditQuerySet):
                                                                                     FROM information_schema.columns As c
                                                                                     WHERE table_name = 'kd_lotsman_documents_hierarcy_recurs_view'
                                                                                       AND c.column_name NOT IN ('parent_id')
-                                                                                         ), ',') || ' FROM kd_lotsman_documents_hierarcy_recurs_view as a where a.document_id=%s' as sqlstmt''',[kwargs.get('document_id')])
+                                                                                         ), ',') || ' FROM kd_lotsman_documents_hierarcy_recurs_view as a where a.document_id=%s' as sqlstmt''', [kwargs.get('document_id')])
 
             sqlstmt = cursor.fetchone()[0]
 
@@ -81,12 +82,8 @@ class Lotsman_documents_hierarcy_viewManager(AuditManager):
             _section = record.attr_name.lower()
             if _section == 'документация':
                 return 'documentation.png'
-            elif _section == 'спецификация':
-                return 'documentation.png'
             elif _section == 'изделие':
                 return 'product.png'
-            elif _section == 'чертеж':
-                return 'documentation.png'
             elif _section == 'комплексы':
                 return 'complexes.png'
             elif _section == 'сборочная единица':
@@ -114,6 +111,14 @@ class Lotsman_documents_hierarcy_viewManager(AuditManager):
 
     @staticmethod
     def getRecord(record):
+        def set_document_icon(record):
+            from kaf_pas.kd.models.lotsman_documents_hierarcy_files import Lotsman_documents_hierarcy_files
+            setAttr(record, 'isLoadedPict', Lotsman_documents_hierarcy_files.objects.filter(lotsman_document_id=record.get('id')).count() > 0)
+            if record.get('isLoadedPict'):
+                setAttr(record, 'icon', 'documentation.png')
+            else:
+                setAttr(record, 'icon', 'documentation_not_loaded.png')
+
         res = {
             'id': record.id,
             'parent_id': record.parent_id,
@@ -164,9 +169,21 @@ class Lotsman_documents_hierarcy_viewManager(AuditManager):
             'attr_code': record.attr_code,
             'attr_name': record.attr_name,
             'isFolder': record.isFolder,
+            'isLoadedPict': False,
             'icon': Lotsman_documents_hierarcy_viewManager.getIcon(record)
         }
-        return DelProps(res)
+        res = DelProps(res)
+
+        _section = record.attr_name.lower()
+        if _section == 'спецификация':
+            set_document_icon(res)
+
+        elif _section == 'чертеж':
+            set_document_icon(res)
+
+        # if res.get('isLoadedPict') == True:
+        #     print(res, end='\n\n')
+        return res
 
     def get_queryset(self):
         return Lotsman_documents_hierarcy_viewQuerySet(self.model, using=self._db)
@@ -252,6 +269,17 @@ class Lotsman_documents_hierarcy_view(AuditModel):
         else:
             return None
 
+    @property
+    def item_name(self):
+        if self.SPC_CLM_NAME != None and self.SPC_CLM_MARK != None:
+            return f'{get_NoneStr(self.SPC_CLM_NAME.value_str)}: {get_NoneStr(self.SPC_CLM_MARK.value_str)}'
+        elif self.SPC_CLM_NAME == None and self.SPC_CLM_MARK != None:
+            return get_NoneStr(self.SPC_CLM_MARK.value_str)
+        elif self.SPC_CLM_NAME != None and self.SPC_CLM_MARK == None:
+            return get_NoneStr(self.SPC_CLM_NAME.value_str)
+        else:
+            return 'Неизвестен'
+
     @property
     def SPC_CLM_MATERIAL_NAME_DOC(self):
         name = f'{self.Наименование_материала.value_str if self.Наименование_материала.value_str else None}'
