@@ -10,7 +10,7 @@ def Spw_attrs_Fetch(request):
         DSResponse(
             request=request,
             data=Spw_attrs.objects.
-                select_related('document', 'attr_type').
+                select_related('attr_type').
                 get_range_rows1(
                 request=request,
                 function=Spw_attrsManager.getRecord
