@@ -1,6 +1,6 @@
 import logging
 
-from django.db.models import TextField
+from django.db.models import TextField, UniqueConstraint, Q
 from django.forms import model_to_dict
 
 from isc_common.fields.code_field import CodeStrictField
@@ -79,7 +79,7 @@ class ContantsManager(BaseRefManager):
 
 
 class Contants(BaseRefHierarcy):
-    code = CodeStrictField(unique=True)
+    code = CodeStrictField()
     value = TextField(null=True, blank=True, db_index=True)
     objects = ContantsManager()
 
@@ -91,3 +91,8 @@ class Contants(BaseRefHierarcy):
 
     class Meta:
         verbose_name = 'Системные константы'
+        constraints = [
+            UniqueConstraint(fields=['code'], condition=Q(parent=None), name='Contants_unique_constraint_0'),
+            UniqueConstraint(fields=['code', 'parent'], name='Contants_unique_constraint_1'),
+        ]
+
